@@ -2,6 +2,16 @@
 import pandas as pd 
 import re ,spacy,emoji
 
+import matplotlib.pyplot as plt
+from urllib.request import urlretrieve as uru 
+from PIL import Image
+import numpy as np
+from wordcloud import WordCloud , ImageColorGenerator
+from collections import Counter
+
+
+
+
 #import coreferee
 
 def coreNLP():
@@ -17,7 +27,7 @@ def coreNLP():
 nlp = coreNLP()
 
 
-#1 count frequence of list
+#1 count frequence of list and word cloud 
 def countFreq(my_list,extra_name=""):
 # Creating an empty dictionary
     freq = {}
@@ -39,6 +49,80 @@ def countFreq(my_list,extra_name=""):
     return df_freq
 
 
+# count frequence dict and dataframe 
+def variablename(var):
+    return [tpl[0] for tpl in filter(lambda x: var is x[1], globals().items())] # get the variable name 
+def countFreq2(my_list,extra_name=""):
+    """ list return frequency dictiaory and dataframe """
+    # Creating an empty dictionary
+    freq = {}
+    for item in my_list:
+        if (item in freq):
+            freq[item] += 1
+        else:
+            freq[item] = 1
+    keys =[]
+    values = []
+    for key, value in freq.items():
+        keys.append(key)
+        values.append(value)
+    keys_name = "".join(variablename(my_list)) + extra_name
+    
+    dlist = {keys_name:keys,(keys_name +'_freq'):values}
+    df_freq = pd.DataFrame(dlist)
+    df_freq = df_freq.sort_values(by= (keys_name +'_freq'), ascending=False)
+    return df_freq, freq
+
+
+# https://github.com/pengKiina/KeypartX/raw/main/images/ta_white.png
+def wordCloud(freq_dict, background_color="turquoise",max_words=200,collocations=False,mask_img = False, save_fig = False,random_state=2,normalize_plurals = False, width=800, height=600):
+  """
+    freq_dict: dictionary of word and frequency 
+    make_img : image address local or url 
+    save_fig:  save wordcould address"""
+
+  if mask_img:
+    try:
+      uru(mask_img,'ta_white.png')
+      mask = np.array(Image.open('ta_white.png')) 
+    except:
+            mask = np.array(Image.open(mask_img)) 
+
+    #font_path ="C:\Videos\Personal_life\R_Python\jiebaDict\SourceHanSerifTC_EL-M\SourceHanSerifTC-Regular.otf"
+    #wc = WordCloud(font_path=font_path, background_color="white",collocations=False,mask=mask, random_state=3,normalize_plurals = False, width=800, height=1000, )
+    wc= WordCloud(background_color=background_color,max_words=max_words,collocations=collocations,mask=mask, random_state=random_state,normalize_plurals = normalize_plurals, width=width, height=height,)
+    wc.generate_from_frequencies(Counter(freq_dict))
+    #create coloring from image
+    image_colors = ImageColorGenerator(mask)
+
+    plt.figure(figsize=(width/100,height/100))
+    #recolor wordcloud and show
+    #plt.imshow(wc.recolor(color_func=image_colors), interpolation="bilinear") 
+    plt.imshow(wc) 
+    plt.axis("off") 
+    if save_fig : 
+       plt.savefig(save_fig,dpi=300)
+       plt.show()
+  else:
+      wc= WordCloud(background_color=background_color,max_words=max_words,collocations=collocations, random_state=random_state,normalize_plurals = normalize_plurals, width=width, height=height,)
+      wc.generate_from_frequencies(Counter(freq_dict))
+      plt.figure(figsize=(width/100,height/100))
+      #plt.figure()
+      #recolor wordcloud and show
+      #plt.imshow(wc.recolor(color_func=image_colors), interpolation="bilinear") 
+      plt.imshow(wc) 
+      plt.axis("off") 
+      if save_fig : 
+        plt.savefig(save_fig,dpi=300)
+        plt.show()
+
+
+
+
+
+
+
+
 #2 coreferee
 #import coreferee, spacy
 #nlp = spacy.load('en_core_web_lg')
